@@ -831,7 +831,7 @@ int main(int argc, char* argv[])
     CHECKML_BEGIN();
 
     /// ファイラでもスクリプトでも共通の環境変数を初期化 ///
-    setenv("VERSION", "4.2.1", 1);
+    setenv("VERSION", "4.2.2", 1);
 
     /// mfiler3のホームディレクトリを保存しておく ///
     char* home = getenv("HOME");
@@ -842,9 +842,12 @@ int main(int argc, char* argv[])
     snprintf(gHomeDir, PATH_MAX, "%s/.mfiler3", home);
 
     if(access(gHomeDir, F_OK) != 0) {
-	char buf[PATH_MAX];
+        char buf[PATH_MAX];
         snprintf(buf, PATH_MAX, "mkdir -p %s", gHomeDir);
-        system(buf);
+        if(system(buf) < 0) {
+            fprintf(stderr, "can't make directory (%s)", gHomeDir);
+            exit(1);
+        }
     }
 
     if(chmod(gHomeDir, S_IRUSR|S_IWUSR|S_IXUSR) < 0) {
